pub enum CallStatus {
Ringing,
InProgress,
Ended,
}Expand description
CallStatus : Current status of the call: - ringing: Call is being established but not yet connected - in_progress: Call is active and participants are connected - ended: Call has been terminated Current status of the call: - ringing: Call is being established but not yet connected - in_progress: Call is active and participants are connected - ended: Call has been terminated
Variants