pub struct ToolInvocation {
pub name: String,
pub description: Option<String>,
pub parameters: HashMap<String, ToolInvocationParametersValue>,
pub result: ToolInvocationResult,
pub start_offset_ms: u32,
pub end_offset_ms: Option<u32>,
}Expand description
ToolInvocation : Details of a tool or function invocation during a call
Fields
name: StringName identifier of the invoked tool or function
description: Option<String>Human-readable description of the tool’s purpose
parameters: HashMap<String, ToolInvocationParametersValue>Parameters provided to the tool during invocation
result: ToolInvocationResultstart_offset_ms: u32Offset in milliseconds from call start when tool was invoked
end_offset_ms: Option<u32>Offset in milliseconds from call start when tool execution completed
Implementations
Sourceimpl ToolInvocation
impl ToolInvocation
Sourcepub fn new(
name: String,
parameters: HashMap<String, ToolInvocationParametersValue>,
result: ToolInvocationResult,
start_offset_ms: u32,
) -> ToolInvocation
pub fn new( name: String, parameters: HashMap<String, ToolInvocationParametersValue>, result: ToolInvocationResult, start_offset_ms: u32, ) -> ToolInvocation
Details of a tool or function invocation during a call